@@ -6,12 +6,12 @@ def bar(progress, total, icon='█', begin='Downloading', show_percent=True):
     Be sure to print a ('\\n') after running the bar function!
     You can find out why ;)
     '''
-    percent = 100 * (progress / total)
+    percent = 100 * (progress / float(total))
     bar = icon * int(percent) + '-' * (100 - int(percent))
     if show_percent == True:
-        print(f'{begin} |{bar}| {percent:.2f}%', end='\r')
+        print(f"\r{begin} |{bar}| {percent:.2f}%", end="")
     else:
-        print(f'{begin} |{bar}|', end='\r')
+        print(f"\r{begin} |{bar}|", end="")
 
 def rotate(begin = 'Downloading', sleep_value = 0.1):
     list = ['|', '/', '-', '\\']
